==> webStore_2.8.2_estable.zip: admin/html_files/componentes/banners/fotos_crear_carpeta.php <==
<?php
	//Creado por Pedro el 13/Febrero/2019 ==> Imagen que permite subir un nivel en los directorios:
	$ruta_actual = '';
	if (isset($fileParams)){
		if (isset($fileParams->args)){
			if (is_array($fileParams->args)){
				if (isset($fileParams->args[1])){
					$ruta_actual = $fileParams->args[1];	// Sí, hay que liar mucho para llegar, pero mejor asegurarse
				}
			}
		}
	}
	
//	if ($ruta_actual != ''){
?>
<!--<button type="button" class="btn btn-success margin-5" data-toggle="modal" data-target="#Modal2">
	View Popup
</button>-->
<div class="col-lg-3 col-md-6">
	<div class="card">
		<div class="el-card-item">
			<div class="el-card-avatar el-overlay-1"> 
				<div class="el-overlay carpeta">
					<ul class="list-style-none el-info">
						<li class="el-item"><a class="el-link" href="javascript:void(0);"data-toggle="modal" data-target="#Modal2"><i class="mdi mdi-folder-plus"></i></a></li>
					</ul>
				</div>
			</div>
			<div class="el-card-content">
				<h4 class="m-b-0"><?=traducir('Crear carpeta');?></h4>
			</div>
		</div>
	</div>
</div>

<!-- Modal -->
<div class="modal fade" id="Modal2" tabindex="-1" role="dialog" aria-labelledby="modalCrearDirectorio" aria-hidden="true">
	<div class="modal-dialog" role="document">
		<div class="modal-content">
			<div class="modal-header">
				<h5 class="modal-title" id="modalCrearDirectorio"><?=traducir('Crear carpeta');?></h5>
				<button type="button" class="close" data-dismiss="modal" aria-label="Close">
					<span aria-hidden="true">&times;</span>
				</button>
			</div>
			<div class="modal-body">
				<?=traducir('Introduzca el nombre de la carpeta a cargar');?>
				<form class="form-horizontal">
					<div class="card-body">
						<div class="form-group row">
							<label for="fname" class="col-sm-3 text-right control-label col-form-label"><?=traducir('Nombre');?></label>
							<div class="col-sm-9">
								<input type="text" class="form-control" id="dirName" name="dirName" placeholder="<?=traducir('Introduzca el nombre de la carpeta');?>">
								<div class="invalid-feedback">
									<?=traducir('Ha ocurrido un problema al crear el directorio. Probablemente ya exista o haya utilizado un nombre incorrecto.');?>
								</div>
							</div>
						</div>
					</div>
				</form>
				<div class="alert alert-secondary text-justify" role="alert">
					<?=traducir('Recuerde que los nombres de carpeta no pueden contener ni puntos "." ni barras "/" ni ningún otro carácter reservado.');?>
				</div>
			</div>
			<div class="modal-footer">
				<button type="button" class="btn btn-secondary" data-dismiss="modal"><?=traducir('Cancelar');?></button>
				<button type="button" class="btn btn-primary" id="btnCrearDirectorio" onclick="
				$('#modalCrearDirectorio').closest('.modal-content').find('form input[name=\'dirName\']').removeClass('is-invalid');
				$('#Modal2').click();
				var dirName = $('#modalCrearDirectorio').closest('.modal-content').find('form input[name=\'dirName\']').val();
				if (dirName != ''){
					dirName = '<?=$ruta_actual;?>' + '/' + dirName;
					var sendData = { 'path' : dirName};
					WS_data_update(
						'FileSystem',
						'createDir',
						sendData,
						'',
						function(data){
							//console.log(data);
							//Comprobamos si hemos recibido 'response'
							var error = true;
							if (data.response != null){
								data.response = JSON.parse(data.response);
								if (data.response.resultado == true){
									//Recargamos la página en la que estamos:
									WS_data_update('','',{},'=\'img_list_change\'',function(data){});
								}else{
									$('#modalCrearDirectorio').closest('.modal-content').find('form input[name=\'dirName\']').addClass('is-invalid');
								}
							}
						}
					);
				}
				
				"><?=traducir('Crear');?></button>
			</div>
			<script>
			document.querySelector('.form-horizontal').addEventListener('submit', function(event) {
				event.preventDefault();
				var evObj = document.createEvent('Events');
				evObj.initEvent('click', true, false);
				document.querySelector('#btnCrearDirectorio').dispatchEvent(evObj);
				document.querySelector('#Modal2').dispatchEvent(evObj);
			});
			</script>
		</div>
	</div>
</div>
<!-- Modal -->

<?php
	//}
	
?>

==> webStore_2.8.9_estable.zip: admin/html_files/componentes/banners/fotos_crear_carpeta.php <==
<?php
	//Creado por Pedro el 13/Febrero/2019 ==> Imagen que permite subir un nivel en los directorios:
	$ruta_actual = (Theme::getLastParam(1)) ? Theme::getLastParam(1) : '';
	
//	if ($ruta_actual != ''){
?>
<!--<button type="button" class="btn btn-success margin-5" data-toggle="modal" data-target="#Modal2">
	View Popup
</button>-->
<div class="col-lg-3 col-md-6">
	<div class="card">
		<div class="el-card-item">
			<div class="el-card-avatar el-overlay-1"> 
				<div class="el-overlay carpeta">
					<ul class="list-style-none el-info">
						<li class="el-item"><a class="el-link" href="javascript:void(0);"data-toggle="modal" data-target="#Modal2"><i class="mdi mdi-folder-plus"></i></a></li>
					</ul>
				</div>
			</div>
			<div class="el-card-content">
				<h4 class="m-b-0"><?=traducir('Crear carpeta');?></h4>
			</div>
		</div>
	</div>
</div>

<!-- Modal -->
<div class="modal fade" id="Modal2" tabindex="-1" role="dialog" aria-labelledby="modalCrearDirectorio" aria-hidden="true">
	<div class="modal-dialog" role="document">
		<div class="modal-content">
			<div class="modal-header">
				<h5 class="modal-title" id="modalCrearDirectorio"><?=traducir('Crear carpeta');?></h5>
				<button type="button" class="close" data-dismiss="modal" aria-label="Close">
					<span aria-hidden="true">&times;</span>
				</button>
			</div>
			<div class="modal-body">
				<?=traducir('Introduzca el nombre de la carpeta a cargar');?>
				<form class="form-horizontal">
					<div class="card-body">
						<div class="form-group row">
							<label for="fname" class="col-sm-3 text-right control-label col-form-label"><?=traducir('Nombre');?></label>
							<div class="col-sm-9">
								<input type="text" class="form-control" id="dirName" name="dirName" placeholder="<?=traducir('Introduzca el nombre de la carpeta');?>">
								<div class="invalid-feedback">
									<?=traducir('Ha ocurrido un problema al crear el directorio. Probablemente ya exista o haya utilizado un nombre incorrecto.');?>
								</div>
							</div>
						</div>
					</div>
				</form>
				<div class="alert alert-secondary text-justify" role="alert">
					<?=traducir('Recuerde que los nombres de carpeta no pueden contener ni puntos "." ni barras "/" ni ningún otro carácter reservado.');?>
				</div>
			</div>
			<div class="modal-footer">
				<button type="button" class="btn btn-secondary" data-dismiss="modal"><?=traducir('Cancelar');?></button>
				<button type="button" class="btn btn-primary" id="btnCrearDirectorio" onclick="
				$('#modalCrearDirectorio').closest('.modal-content').find('form input[name=\'dirName\']').removeClass('is-invalid');
				$('#Modal2').click();
				var dirName = $('#modalCrearDirectorio').closest('.modal-content').find('form input[name=\'dirName\']').val();
				if (dirName != ''){
					dirName = '<?=$ruta_actual;?>' + '/' + dirName;
					var sendData = { 'path' : dirName};
					WS_data_update(
						'FileSystem',
						'createDir',
						sendData,
						'',
						function(data){
							//console.log(data);
							//Comprobamos si hemos recibido 'response'
							var error = true;
							if (data.response != null){
								data.response = JSON.parse(data.response);
								if (data.response.resultado == true){
									console.log(data.response);
									//Recargamos la página en la que estamos:
									WS_data_update('FileSystem','createDir',{},'=\'img_list_change\'',function(data){});
								}else{
									$('#modalCrearDirectorio').closest('.modal-content').find('form input[name=\'dirName\']').addClass('is-invalid');
								}
							}
						}
					);
				}
				
				"><?=traducir('Crear');?></button>
			</div>
			<script>
			document.querySelector('.form-horizontal').addEventListener('submit', function(event) {
				event.preventDefault();
				var evObj = document.createEvent('Events');
				evObj.initEvent('click', true, false);
				document.querySelector('#btnCrearDirectorio').dispatchEvent(evObj);
				document.querySelector('#Modal2').dispatchEvent(evObj);
			});
			</script>
		</div>
	</div>
</div>
<!-- Modal -->

<?php
	//}
	
?>
